<?php

class Click_To_Pop_Admin {
    private $plugin_name;
    private $version;

    public function __construct($plugin_name, $version) {
        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_action('wp_ajax_delete_popup', array($this, 'delete_popup'));
        add_action('wp_ajax_save_popup', array($this, 'save_popup'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_preview_assets'));
    }

    public function enqueue_styles() {
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/click-to-pop-admin.css', array(), $this->version, 'all');
    }

    public function enqueue_scripts() {
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/click-to-pop-admin.js', array('jquery'), $this->version, false);
    }

    public function add_plugin_admin_menu() {
        add_menu_page(
            'Click to Pop', 
            'Click to Pop', 
            'manage_options', 
            $this->plugin_name, 
            array($this, 'display_plugin_setup_page'),
            'dashicons-feedback',
            26
        );

        add_submenu_page(
            $this->plugin_name,
            'Popups',
            'Popups',
            'manage_options',
            $this->plugin_name . '-popups',
            array($this, 'display_popups_page')
        );

        add_submenu_page(
            $this->plugin_name,
            'Add New Popup',
            'Add New',
            'manage_options',
            $this->plugin_name . '-add-new',
            array($this, 'display_add_new_page')
        );

        add_submenu_page(
            $this->plugin_name,
            'Subscribers',
            'Subscribers',
            'manage_options',
            $this->plugin_name . '-subscribers',
            array($this, 'display_subscribers_page')
        );

        add_submenu_page(
            $this->plugin_name,
            'Learn More',
            'Learn More',
            'manage_options',
            'https://joevics.wordpress.com/',
            null
        );

        remove_submenu_page($this->plugin_name, $this->plugin_name);
    }

    public function display_plugin_setup_page() {
        include_once 'partials/click-to-pop-admin-display.php';
    }

    public function display_popups_page() {
        include_once 'partials/click-to-pop-admin-popups.php';
    }

    public function display_add_new_page() {
        include_once 'partials/click-to-pop-admin-add-new.php';
    }

    public function display_subscribers_page() {
        include_once 'partials/click-to-pop-admin-subscribers.php';
    }

    public function delete_popup() {
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'delete_popup_nonce')) {
            wp_send_json_error('Invalid nonce');
        }

        $id = intval($_POST['id']);
        $result = Click_To_Pop_DB::delete_popup($id);

        if ($result) {
            wp_send_json_success();
        } else {
            wp_send_json_error('Failed to delete popup');
        }
    }

    public function save_popup() {
        if (!isset($_POST['ctp_nonce']) || !wp_verify_nonce($_POST['ctp_nonce'], 'save_popup')) {
            wp_send_json_error('Invalid nonce');
        }

        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = sanitize_text_field($_POST['popup_name']);
        $settings = array(
            'popup_title' => sanitize_text_field($_POST['popup_title']),
            'popup_description' => sanitize_textarea_field($_POST['popup_description']),
            'button_text' => sanitize_text_field($_POST['button_text']),
            'show_name_field' => isset($_POST['show_name_field']) ? 1 : 0,
            'popup_background_color' => sanitize_hex_color($_POST['popup_background_color']),
            'popup_text_color' => sanitize_hex_color($_POST['popup_text_color']),
            'submit_button_color' => sanitize_hex_color($_POST['submit_button_color']),
            'trigger_button_text' => sanitize_text_field($_POST['trigger_button_text']),
            'trigger_button_color' => sanitize_hex_color($_POST['trigger_button_color']),
            'trigger_button_text_color' => sanitize_hex_color($_POST['trigger_button_text_color']),
        );

        if ($id) {
            $result = Click_To_Pop_DB::update_popup($id, $name, $settings);
        } else {
            $result = Click_To_Pop_DB::create_popup($name, $settings);
        }

        if ($result) {
            wp_send_json_success('Popup saved successfully');
        } else {
            wp_send_json_error('Failed to save popup');
        }
    }

    public function enqueue_preview_assets($hook) {
        if ('click-to-pop_page_click-to-pop-add-new' !== $hook) {
            return;
        }

        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script('ctp-admin-preview', plugin_dir_url(__FILE__) . 'js/click-to-pop-admin-preview.js', array('jquery', 'wp-color-picker'), $this->version, true);
    }

    public function handle_form_submission() {
        if (!isset($_POST['ctp_nonce']) || !wp_verify_nonce($_POST['ctp_nonce'], 'ctp_submit_form')) {
            wp_send_json_error('Invalid request');
        }

        if (!isset($_POST['popup_id']) || !isset($_POST['email'])) {
            wp_send_json_error('Missing required fields');
        }

        $popup_id = intval($_POST['popup_id']);
        $email = sanitize_email($_POST['email']);
        $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';

        if (!is_email($email)) {
            wp_send_json_error('Please enter a valid email address.');
        }

        $result = Click_To_Pop_DB::add_subscriber($popup_id, $email, $name);

        if ($result) {
            wp_send_json_success('Thank you for subscribing!');
        } else {
            wp_send_json_error('An error occurred. Please try again.');
        }
    }
}