<?php
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$popup = $id ? Click_To_Pop_DB::get_popup($id) : null;
$settings = $popup ? json_decode($popup->settings, true) : array();
?>
<div class="wrap">
    <h1 class="wp-heading-inline"><?php echo $id ? 'Edit Popup' : 'Add New Popup'; ?></h1>
    <hr class="wp-header-end">

    <div class="ctp-container">
        <div class="ctp-settings">
            <form method="post" id="ctp-form">
                <?php wp_nonce_field('save_popup', 'ctp_nonce'); ?>
                <?php if ($id) : ?>
                    <input type="hidden" name="id" value="<?php echo $id; ?>">
                <?php endif; ?>

                <table class="form-table">
                    <tr>
                        <th scope="row"><label for="popup_name">Popup Name</label></th>
                        <td><input name="popup_name" id="popup_name" type="text" value="<?php echo esc_attr($popup ? $popup->name : ''); ?>" class="regular-text" required></td>
                    </tr>
                </table>

                <h2 class="nav-tab-wrapper">
                    <a href="#general-settings" class="nav-tab nav-tab-active">General Settings</a>
                    <a href="#design-settings" class="nav-tab">Design Settings</a>
                </h2>

                <div id="general-settings" class="tab-content">
                    <table class="form-table">
                        <tr>
                            <th scope="row"><label for="popup_title">Popup Title</label></th>
                            <td><input name="popup_title" id="popup_title" type="text" value="<?php echo esc_attr($settings['popup_title'] ?? ''); ?>" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="popup_description">Popup Description</label></th>
                            <td><textarea name="popup_description" id="popup_description" rows="5" cols="50"><?php echo esc_textarea($settings['popup_description'] ?? ''); ?></textarea></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="button_text">Button Text</label></th>
                            <td><input name="button_text" id="button_text" type="text" value="<?php echo esc_attr($settings['button_text'] ?? 'Subscribe'); ?>" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="show_name_field">Show Name Field</label></th>
                            <td><input name="show_name_field" id="show_name_field" type="checkbox" value="1" <?php checked($settings['show_name_field'] ?? false); ?>></td>
                        </tr>
                    </table>
                </div>

                <div id="design-settings" class="tab-content" style="display:none;">
                    <table class="form-table">
                        <tr>
                            <th scope="row"><label for="popup_background_color">Popup Background Color</label></th>
                            <td><input name="popup_background_color" id="popup_background_color" type="color" value="<?php echo esc_attr($settings['popup_background_color'] ?? '#ffffff'); ?>"></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="popup_text_color">Popup Text Color</label></th>
                            <td><input name="popup_text_color" id="popup_text_color" type="color" value="<?php echo esc_attr($settings['popup_text_color'] ?? '#000000'); ?>"></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="submit_button_color">Submit Button Color</label></th>
                            <td><input name="submit_button_color" id="submit_button_color" type="color" value="<?php echo esc_attr($settings['submit_button_color'] ?? '#4CAF50'); ?>"></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="trigger_button_text">Trigger Button Text</label></th>
                            <td><input name="trigger_button_text" id="trigger_button_text" type="text" value="<?php echo esc_attr($settings['trigger_button_text'] ?? 'Open Popup'); ?>" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="trigger_button_color">Trigger Button Color</label></th>
                            <td><input name="trigger_button_color" id="trigger_button_color" type="color" value="<?php echo esc_attr($settings['trigger_button_color'] ?? '#0073aa'); ?>"></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="trigger_button_text_color">Trigger Button Text Color</label></th>
                            <td><input name="trigger_button_text_color" id="trigger_button_text_color" type="color" value="<?php echo esc_attr($settings['trigger_button_text_color'] ?? '#ffffff'); ?>"></td>
                        </tr>
                    </table>
                </div>

                <?php submit_button('Save Popup'); ?>
            </form>
        </div>

        <div class="ctp-preview">
            <h2>Preview</h2>
            <div id="ctp-preview-trigger" class="button">Open Popup</div>
            <div id="ctp-preview-popup" class="ctp-popup" style="display: none;">
                <div class="ctp-popup-content">
                    <span class="ctp-close">&times;</span>
                    <h2 id="preview-popup-title">Subscribe to Our Newsletter</h2>
                    <p id="preview-popup-description"></p>
                    <form id="preview-form">
                        <div id="preview-name-field" style="display: none;">
                            <input type="text" placeholder="Your Name" disabled>
                        </div>
                        <input type="email" placeholder="Your Email" disabled>
                        <button type="button" id="preview-submit-button">Subscribe</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
.ctp-container {
    display: flex;
    justify-content: space-between;
}
.ctp-settings {
    width: 60%;
}
.ctp-preview {
    width: 35%;
    position: sticky;
    top: 32px;
}
.ctp-popup {
    position: relative;
    background-color: rgba(0,0,0,0.5);
    width: 100%;
    height: 300px;
}
.ctp-popup-content {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    background-color: #fff;
    padding: 20px;
    border-radius: 5px;
    width: 80%;
}
</style>

<script>
jQuery(document).ready(function($) {
    $('.nav-tab').on('click', function(e) {
        e.preventDefault();
        $('.nav-tab').removeClass('nav-tab-active');
        $(this).addClass('nav-tab-active');
        $('.tab-content').hide();
        $($(this).attr('href')).show();
    });

    function updatePreview() {
        var title = $('#popup_title').val();
        var description = $('#popup_description').val();
        var buttonText = $('#button_text').val();
        var showNameField = $('#show_name_field').is(':checked');
        var bgColor = $('#popup_background_color').val();
        var textColor = $('#popup_text_color').val();
        var buttonColor = $('#submit_button_color').val();
        var triggerText = $('#trigger_button_text').val();
        var triggerColor = $('#trigger_button_color').val();
        var triggerTextColor = $('#trigger_button_text_color').val();

        $('#preview-popup-title').text(title);
        $('#preview-popup-description').text(description);
        $('#preview-submit-button').text(buttonText);
        $('#preview-name-field').toggle(showNameField);
        $('.ctp-popup-content').css({
            'background-color': bgColor,
            'color': textColor
        });
        $('#preview-submit-button').css('background-color', buttonColor);
        $('#ctp-preview-trigger').text(triggerText).css({
            'background-color': triggerColor,
            'color': triggerTextColor
        });
    }

    $('#ctp-form input, #ctp-form textarea').on('input', updatePreview);
    $('#show_name_field').on('change', updatePreview);

    $('#ctp-preview-trigger').on('click', function() {
        $('#ctp-preview-popup').show();
    });
    $('.ctp-close').on('click', function() {
        $('#ctp-preview-popup').hide();
    });

    updatePreview();

    $('#ctp-form').on('submit', function(e) {
        e.preventDefault();
        var formData = $(this).serialize();
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: formData + '&action=save_popup',
            success: function(response) {
                if (response.success) {
                    alert('Popup saved successfully!');
                    window.location.href = '<?php echo admin_url('admin.php?page=' . $this->plugin_name . '-popups'); ?>';
                } else {
                    alert('Error: ' + response.data);
                }
            },
            error: function() {
                alert('An error occurred. Please try again.');
            }
        });
    });
});
</script>