<?php

class Click_To_Pop_DB {
    private static $popups_table;
    private static $subscribers_table;

    public static function init() {
        global $wpdb;
        self::$popups_table = $wpdb->prefix . 'ctp_popups';
        self::$subscribers_table = $wpdb->prefix . 'ctp_subscribers';
    }

    public static function create_tables() {
        global $wpdb;
        
        self::init(); // Ensure table names are set

        $charset_collate = $wpdb->get_charset_collate();

        $popups_table = self::$popups_table;
        $subscribers_table = self::$subscribers_table;

        // Check if tables exist
        $popups_table_exists = $wpdb->get_var("SHOW TABLES LIKE '$popups_table'") == $popups_table;
        $subscribers_table_exists = $wpdb->get_var("SHOW TABLES LIKE '$subscribers_table'") == $subscribers_table;

        if (!$popups_table_exists) {
            $sql = "CREATE TABLE $popups_table (
                id mediumint(9) NOT NULL AUTO_INCREMENT,
                name varchar(255) NOT NULL,
                settings longtext NOT NULL,
                created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
                updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP NOT NULL,
                PRIMARY KEY  (id)
            ) $charset_collate;";

            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            dbDelta($sql);
        }

        if (!$subscribers_table_exists) {
            $sql = "CREATE TABLE $subscribers_table (
                id mediumint(9) NOT NULL AUTO_INCREMENT,
                popup_id mediumint(9) NOT NULL,
                email varchar(255) NOT NULL,
                name varchar(255),
                subscribed_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
                PRIMARY KEY  (id),
                KEY popup_id (popup_id)
            ) $charset_collate;";

            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            dbDelta($sql);
        }
    }

    public static function get_popups() {
        global $wpdb;
        return $wpdb->get_results("SELECT * FROM " . self::$popups_table . " ORDER BY created_at DESC");
    }

    public static function get_popup($id) {
        global $wpdb;
        return $wpdb->get_row($wpdb->prepare("SELECT * FROM " . self::$popups_table . " WHERE id = %d", $id));
    }

    public static function create_popup($name, $settings) {
        global $wpdb;
        $result = $wpdb->insert(
            self::$popups_table,
            array(
                'name' => $name,
                'settings' => json_encode($settings)
            ),
            array('%s', '%s')
        );
        return $result ? $wpdb->insert_id : false;
    }

    public static function update_popup($id, $name, $settings) {
        global $wpdb;
        return $wpdb->update(
            self::$popups_table,
            array(
                'name' => $name,
                'settings' => json_encode($settings),
                'updated_at' => current_time('mysql')
            ),
            array('id' => $id),
            array('%s', '%s', '%s'),
            array('%d')
        );
    }

    public static function delete_popup($id) {
        global $wpdb;
        return $wpdb->delete(self::$popups_table, array('id' => $id), array('%d'));
    }

    public static function add_subscriber($popup_id, $email, $name = '') {
        global $wpdb;
        return $wpdb->insert(
            self::$subscribers_table,
            array(
                'popup_id' => $popup_id,
                'email' => $email,
                'name' => $name
            ),
            array('%d', '%s', '%s')
        );
    }

    public static function get_subscribers($popup_id = null) {
        global $wpdb;
        if ($popup_id === null) {
            return $wpdb->get_results("SELECT * FROM " . self::$subscribers_table . " ORDER BY subscribed_at DESC");
        } else {
            return $wpdb->get_results($wpdb->prepare("SELECT * FROM " . self::$subscribers_table . " WHERE popup_id = %d ORDER BY subscribed_at DESC", $popup_id));
        }
    }

    public static function delete_subscriber($id) {
        global $wpdb;
        return $wpdb->delete(self::$subscribers_table, array('id' => $id), array('%d'));
    }

    public static function get_popup_name($popup_id) {
        global $wpdb;
        return $wpdb->get_var($wpdb->prepare("SELECT name FROM " . self::$popups_table . " WHERE id = %d", $popup_id));
    }
}