<?php

class Click_To_Pop_Public {
    private $plugin_name;
    private $version;

    public function __construct($plugin_name, $version) {
        $this->plugin_name = $plugin_name;
        $this->version = $version;

       // Add this line to register the shortcode
        add_shortcode('click_to_pop', array($this, 'shortcode_output'));
    }

    public function enqueue_styles() {
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/click-to-pop-public.css', array(), $this->version, 'all');
    }

    public function enqueue_scripts() {
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/click-to-pop-public.js', array('jquery'), $this->version, false);
        wp_localize_script($this->plugin_name, 'ctp_ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
    }

    public function display_popups() {
        $popups = Click_To_Pop_DB::get_popups();
        foreach ($popups as $popup) {
            $this->render_popup($popup);
        }
    }

    public function shortcode_output($atts) {
        $atts = shortcode_atts(array(
            'id' => '',
        ), $atts, 'click_to_pop');

        $popup_id = intval($atts['id']);
        $popup = Click_To_Pop_DB::get_popup($popup_id);

        if (!$popup) {
            return ''; // Return empty if popup doesn't exist
        }

        $settings = json_decode($popup->settings, true);
        $trigger_text = isset($settings['trigger_button_text']) ? $settings['trigger_button_text'] : 'Open Popup';
        $trigger_color = isset($settings['trigger_button_color']) ? $settings['trigger_button_color'] : '#0073aa';
        $trigger_text_color = isset($settings['trigger_button_text_color']) ? $settings['trigger_button_text_color'] : '#ffffff';

        $button_style = "background-color: {$trigger_color}; color: {$trigger_text_color}; padding: 10px 15px; border: none; border-radius: 4px; cursor: pointer;";

        return "<button class='ctp-trigger' data-popup-id='{$popup_id}' style='{$button_style}'>{$trigger_text}</button>";
    }

    private function render_popup($popup) {
        $settings = json_decode($popup->settings, true);
        ?>
        <div id="ctp-popup-<?php echo $popup->id; ?>" class="ctp-popup" style="display: none;">
            <div class="ctp-popup-content" style="background-color: <?php echo esc_attr($settings['popup_background_color']); ?>; color: <?php echo esc_attr($settings['popup_text_color']); ?>;">
                <span class="ctp-close">&times;</span>
                <div class="ctp-popup-header">
                    <h2><?php echo esc_html($settings['popup_title']); ?></h2>
                    <p><?php echo esc_html($settings['popup_description']); ?></p>
                </div>
                <form class="ctp-form" data-popup-id="<?php echo $popup->id; ?>">
                    <?php wp_nonce_field('ctp_submit_form', 'ctp_nonce'); ?>
                    <input type="hidden" name="action" value="ctp_submit_form">
                    <input type="hidden" name="popup_id" value="<?php echo $popup->id; ?>">
                    <?php if ($settings['show_name_field']) : ?>
                        <input type="text" name="name" placeholder="Your Name" required>
                    <?php endif; ?>
                    <input type="email" name="email" placeholder="Your Email" required>
                    <button type="submit" style="background-color: <?php echo esc_attr($settings['submit_button_color']); ?>;">
                        <?php echo esc_html($settings['button_text']); ?>
                    </button>
                </form>
                <div class="ctp-message"></div>
            </div>
        </div>
        <?php
    }
}